@@ -2,8 +2,8 @@ from __future__ import division
 import numpy
 import scipy
 import networkx
-from FARZ import *
-from models import *
+from .FARZ import *
+from .models import *
 
 import matplotlib.pyplot as pyplot
 
